<?php

	/**
	 * Ceska lokalizace phpPgAdmin-u.
	 * Zalozeno na slovenske lokalizaci. Thx.
	 *                                      libor(at)conet.cz
	 */

	// Language and character set
	$lang['applang'] = '&#268;esky';
	$lang['appcharset'] = 'utf-8';
	$lang['applocale'] = 'cs_CZ';
	$lang['appdbencoding'] = 'UNICODE';
	$lang['applangdir'] = 'ltr';

	// Basic strings
	$lang['strintro'] = 'V&#237;tejte v phpPgAdminu.';
	$lang['strlogin'] = 'P&#345;ihl&#225;&#353;en&#237;';
	$lang['strppahome'] = 'Domovsk&#225; str&#225;nka phpPgAdmin';
	$lang['strpgsqlhome'] = 'Domovsk&#225; str&#225;nka PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'Lok&#225;ln&#237; dokumentace k PostgreSQL';
	$lang['strreportbug'] = 'Nahl&#225;sit chybu';
	$lang['strviewfaq'] = 'Prohl&#233;dnout FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	$lang['strloginfailed'] = 'P&#345;ihl&#225;&#353;en&#237; selhalo';
	$lang['strserver'] = 'Server';
	$lang['strlogout'] = 'Odhl&#225;sit';
	$lang['strowner'] = 'Vlastn&#237;k';
	$lang['strlogindisallowed'] = 'P&#345;ihl&#225;&#353;en&#237; zak&#225;z&#225;no';
	$lang['straction'] = 'Akce';
	$lang['stractions'] = 'Akce';
	$lang['strname'] = 'Jm&#233;no';
	$lang['strdefinition'] = 'Definice';
	$lang['stroperators'] = 'Oper&#225;tory';
	$lang['straggregates'] = 'Agreg&#225;ty';
	$lang['strproperties'] = 'Vlastnosti';
	$lang['strbrowse'] = 'P&#345;ehled';
	$lang['strdrop'] = 'Smazat';
	$lang['strdropped'] = 'Smazan&#253;';
	$lang['strnull'] = 'Nulov&#253;';
	$lang['strnotnull'] = 'Nenulov&#253;';
	$lang['strprev'] = 'P&#345;edchoz&#237;';
	$lang['strnext'] = 'Dal&#353;&#237;';
	$lang['strfailed'] = 'Selhalo';
	$lang['strcreate'] = 'Vytvo&#345;it';
	$lang['strfirst'] = '&lt;&lt; Prvn&#237;';
	$lang['strlast'] = 'Posledn&#237; &gt;&gt;';
	$lang['strcreated'] = 'Vytvo&#345;en&#233;';
	$lang['strcomment'] = 'Koment&#225;&#345;';
	$lang['strlength'] = 'D&#233;lka';
	$lang['strdefault'] = 'P&#345;edvolen&#233;';
	$lang['stralter'] = 'Zm&#283;nit';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'Storno';
	$lang['strsave'] = 'Ulo&#382;it';
	$lang['strreset'] = 'Reset';
	$lang['strinsert'] = 'Vlo&#382;it';
	$lang['strselect'] = 'Vybrat';
	$lang['strdelete'] = 'Smazat';
	$lang['strupdate'] = 'Aktualizovat';
	$lang['strreferences'] = 'Reference';
	$lang['stryes'] = 'Yo';
	$lang['strno'] = 'Ne';
	$lang['stredit'] = 'Upravit';
	$lang['strcolumns'] = 'Sloupce';
	$lang['strtrue'] = 'PRAVDA';
	$lang['strfalse'] = 'NEPRAVDA';
	$lang['strrows'] = '&#344;&#225;dky';
	$lang['strexample'] = 'nap&#345;.';
	$lang['strback'] = 'Zp&#283;t';
	$lang['strrowsaff'] = '&#345;&#225;dk&#367; zm&#283;n&#283;no.';
	$lang['strobjects'] = 'objekt&#367;';
	$lang['strqueryresults'] = 'V&#253;sledky dotazu';
	$lang['strshow'] = 'Uk&#225;zat';
	$lang['strempty'] = 'Vypr&#225;zdnit';
	$lang['strlanguage'] = 'Jazyk';
	$lang['strencoding'] = 'K&#243;dovan&#237;';
	$lang['strvalue'] = 'Hodnota';
	$lang['strunique'] = 'Unik&#225;tn&#237;';
	$lang['strprimary'] = 'Prim&#225;rn&#237;';
	$lang['strexport'] = 'Exportovat';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = 'Vykonej';
	$lang['strimport'] = 'Import';
	$lang['stradmin'] = 'Admin';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analyzovat';
	$lang['strclusterindex'] = 'Cluster';
	$lang['strreindex'] = 'Reindex';
	$lang['strrun'] = 'Spustit';
	$lang['strclustered'] = 'Clustered?';
	$lang['stradd'] = 'P&#345;idat';
	$lang['strevent'] = 'Ud&#225;lost';
	$lang['strwhere'] = 'Kde';
	$lang['strinstead'] = 'Ud&#283;lat nam&#237;sto';
	$lang['strwhen'] = 'Kdy&#382;';
	$lang['strformat'] = 'Form&#225;t';

	// Error handling
	$lang['strdata'] = 'Data';
	$lang['strconfirm'] = 'Potvrzen&#237;';
	$lang['strexpression'] = 'V&#253;raz';
	$lang['strellipsis'] = '...';
	$lang['strexpand'] = 'Rozbal';
	$lang['strcollapse'] = 'Sbal';
	$lang['strexplain'] = 'Vysv&#283;tli';
	$lang['strexplainanalyze'] = 'Vysv&#283;tli anal&#253;zu';
	$lang['strfind'] = 'Hledej';
	$lang['stroptions'] = 'Nastaven&#237;';
	$lang['strrefresh'] = 'Obnov';
	$lang['strdownload'] = 'St&#225;hnout';
	$lang['strdownloadgzipped'] = 'Komprimovat gzipem a st&#225;hnout';
	$lang['strinfo'] = 'Info';
	$lang['stroids'] = 'OIDy';
	$lang['stradvanced'] = 'Pokro&#269;il&#233;';
	$lang['strvariables'] = 'Prom&#283;nn&#233;';
	$lang['strprocess'] = 'Proces';
	$lang['strprocesses'] = 'Processy';
	$lang['strsetting'] = 'Nastaven&#237;';
	$lang['strparameters'] = 'Parametry';
	$lang['streditsql'] = 'Uprav SQL';
	$lang['strpaginate'] = 'Str&#225;nkov&#225;n&#237; v&#253;sledk&#367;';
	$lang['strstarttime'] = 'Po&#269;&#225;te&#269;n&#237; &#269;as';
	$lang['strbadconfig'] = 'Your config.inc.php is out of date. You will need to regenerate it from the new config.inc.php-dist.';
	$lang['strnotloaded'] = 'PHP nen&#237; zakompilov&#225;no s podporou PostgreSQL';
	$lang['strbadschema'] = 'Nastaveno &#353;patn&#233; sch&#233;ma.';
	$lang['strbadencoding'] = 'Nastaven&#237; k&#243;dovan&#237; v datab&#225;ze selhalo.';
	$lang['strsqlerror'] = 'SQL chyba:';
	$lang['strinstatement'] = 'Ve v&#253;razu:';
	$lang['strinvalidparam'] = 'Chybn&#233; parametry skriptu.';
	$lang['strnodata'] = 'Nenalezeny &#382;&#225;dn&#233; z&#225;znamy.';

	// Tables
	$lang['strnoobjects'] = '&#381;&#225;dn&#233; objekty nenalezeny.';
	$lang['strrownotunique'] = '&#381;&#225;dn&#253; jednozna&#269;n&#253; identifik&#225;tor pro tento &#345;&#225;dek.';
	$lang['strnoreportsdb'] = 'Nevytvo&#345;il jsi datab&#225;z&#237; pro reporty. P&#345;&#237;slu&#353;n&#233; pokyny najde&#353; v souboru INSTALL.';
	$lang['strtable'] = 'Tabulka';
	$lang['strtables'] = 'Tabulky';
	$lang['strshowalltables'] = 'Zobrazit v&#353;echny tabulky';
	$lang['strnotables'] = 'Nenalezeny &#382;&#225;dn&#233; tabulky.';
	$lang['strnotable'] = 'Nenalezena &#382;&#225;dn&#225; tabulka.';
	$lang['strcreatetable'] = 'Vytvo&#345;it tabulku';
	$lang['strtablename'] = 'N&#225;zev tabulky';
	$lang['strtableneedsname'] = 'Mus&#237;&#353; zadat n&#225;zov tabulky.';
	$lang['strtableneedsfield'] = 'Mus&#237;&#353; zadat aspo&#328; jedno pole.';
	$lang['strtableneedscols'] = 'Tables require a valid number of columns.';
	$lang['strtablecreated'] = 'Tabulka vytvo&#345;en&#225;.';
	$lang['strtablecreatedbad'] = 'Tabulka nebola vytvo&#345;en&#225;.';
	$lang['strconfdroptable'] = 'Opravdu chce&#353; odstranit tabulku &quot;%s&quot;?';
	$lang['strtabledropped'] = 'Tabulka odstran&#283;n&#225;.';
	$lang['strtabledroppedbad'] = 'Tabulka nebyla odstran&#283;n&#225;.';
	$lang['strconfemptytable'] = 'Opravdu chce&#353; vypr&#225;zdnit tabulku &quot;%s&quot;?';
	$lang['strtableemptied'] = 'Tabulka vypr&#225;zdn&#283;na.';
	$lang['strtableemptiedbad'] = 'Tabulka nebyla vypr&#225;zdn&#283;na.';
	$lang['strinsertrow'] = 'Vlo&#382;it &#345;&#225;dek';
	$lang['strrowinserted'] = '&#344;&#225;dek vlo&#382;en.';
	$lang['strrowinsertedbad'] = '&#344;&#225;dek nebyl vlo&#382;en.';
	$lang['streditrow'] = 'Upravit &#345;&#225;dek';
	$lang['strrowupdated'] = '&#344;&#225;dek upraven.';
	$lang['strrowupdatedbad'] = '&#344;&#225;dek nebyl upraven.';
	$lang['strdeleterow'] = 'Smazat &#345;&#225;dek';
	$lang['strconfdeleterow'] = 'Opravdu chce&#353; smazat tento &#345;&#225;dek?';
	$lang['strrowdeleted'] = '&#344;&#225;dek smaz&#225;n.';
	$lang['strrowdeletedbad'] = '&#344;&#225;dek nebyl smaz&#225;n.';
	$lang['strsaveandrepeat'] = 'Ulo&#382;it &amp; opakovat';
	$lang['strfield'] = 'Pole';
	$lang['strfields'] = 'Pole';
	$lang['strnumfields'] = 'Po&#269;et pol&#237;';
	$lang['strfieldneedsname'] = 'Mus&#237;&#353; pomenovat pole';
	$lang['strselectneedscol'] = 'Mus&#237;&#353; vybrat aspo&#328; jeden stoupec';
	$lang['straltercolumn'] = 'Zm&#283;nit sloupec';
	$lang['strselectallfields'] = 'Ozna&#269; v&#353;echny pole';
	$lang['strcolumnaltered'] = 'Sloupec zm&#283;n&#283;n&#253;.';
	$lang['strselectunary'] = 'Un&#225;rn&#237; oper&#225;tory nemohou m&#237;t hodnoty.';
	$lang['strcolumnalteredbad'] = 'Sloupec nebyl zm&#283;n&#283;n&#253;.';
	$lang['strconfdropcolumn'] = 'Opravdu chce&#353; smazat sloupec &quot;%s&quot; z tabulky &quot;%s&quot;?';
	$lang['strcolumndropped'] = 'Sloupec smaz&#225;n.';
	$lang['strcolumndroppedbad'] = 'Sloupec nebyl smaz&#225;n.';
	$lang['straddcolumn'] = 'P&#345;idat sloupec';
	$lang['strcolumnadded'] = 'Sloupec p&#345;idan&#253;.';
	$lang['strcolumnaddedbad'] = 'Sloupec nebyl p&#345;idan&#253;.';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = 'Tabulka zm&#283;n&#283;na.';
	$lang['strtablealteredbad'] = 'Zm&#283;na tabulky se nepoda&#345;ila.';

	$lang['strstructureonly'] = 'Pouze struktura';
	$lang['strstructureanddata'] = 'Struktura a data';
	// Users
	$lang['struser'] = 'U&#382;ivatel';
	$lang['strusername'] = 'Jm&#233;no u&#382;ivatele';
	$lang['strpassword'] = 'Heslo';
	$lang['strsuper'] = 'Superuser?';
	$lang['strcreatedb'] = 'Vytv&#225;&#345;et DB?';
	$lang['strexpires'] = 'Expiruje';
	$lang['strsessiondefaults'] = 'Standardn&#237; hodnoty session';
	$lang['strnousers'] = 'Nenalezen &#382;&#225;dn&#253; u&#382;ivatel.';
	$lang['struserupdated'] = 'U&#382;ivatel upraven.';
	$lang['struserupdatedbad'] = 'U&#382;ivatel nebyl upraven.';
	$lang['strshowallusers'] = 'Zobrazit v&#353;echny u&#382;ivatele';
	$lang['strcreateuser'] = 'Vytvo&#345;it u&#382;ivatele';
	$lang['struserneedsname'] = 'Mus&#237;te zadat jm&#233;no u&#382;ivatele.';
	$lang['strusercreated'] = 'U&#382;&#237;vatel vytvo&#345;en&#253;.';
	$lang['strusercreatedbad'] = 'U&#382;&#237;vatel nebyl vytvo&#345;en&#253;.';
	$lang['strconfdropuser'] = 'Opravdu chce&#353; smazat u&#382;ivatele &quot;%s&quot;?';
	$lang['struserdropped'] = 'U&#382;ivatel smaz&#225;n.';
	$lang['struserdroppedbad'] = 'U&#382;ivatel nebyl smaz&#225;n.';
	$lang['straccount'] = '&#218;&#269;et';
	$lang['strchangepassword'] = 'Zm&#283;na hesla';
	$lang['strpasswordchanged'] = 'Heslo zm&#283;n&#283;no.';
	$lang['strpasswordchangedbad'] = 'Zm&#283;na hesla se nepoda&#345;ila.';
	$lang['strpasswordshort'] = 'Heslo je p&#345;&#237;li&#353; kr&#225;tk&#233;.';
	$lang['strpasswordconfirm'] = 'Heslo a jeho ov&#283;&#345;en&#237; neodpov&#237;d&#225;.';
		
	// Groups
	$lang['strgroup'] = 'Skupina';
	$lang['strgroups'] = 'Skupiny';
	$lang['strnogroups'] = 'Nebyly nalezeny &#382;&#225;dn&#233; skupiny.';
	$lang['strcreategroup'] = 'Vytvo&#345;it skupinu';
	$lang['strshowallgroups'] = 'Zobrazit v&#353;echny skupiny';
	$lang['strgroupneedsname'] = 'Mus&#237;&#353; zadat jm&#233;no skupiny.';
	$lang['strgroupcreated'] = 'Skupina vytvo&#345;en&#225;.';
	$lang['strgroupcreatedbad'] = 'Skupina nebyla vytvo&#345;en&#225;.';
	$lang['strconfdropgroup'] = 'Opravdu chce&#353; smazat skupinu &quot;%s&quot;?';
	$lang['strgroupdropped'] = 'Skupina smaz&#225;na.';
	$lang['strgroupdroppedbad'] = 'Skupina nebyla smaz&#225;na.';
	$lang['straddmember'] = 'P&#345;idej &#269;lena';
	$lang['strmemberadded'] = '&#268;len p&#345;id&#225;n.';
	$lang['strmemberaddedbad'] = 'P&#345;id&#225;n&#237; &#269;lena se nepovedlo.';
	$lang['strdropmember'] = 'Odstra&#328; &#269;lena';
	$lang['strconfdropmember'] = 'Jse&#353; si opravdu jist, &#382;e chce&#353; odstranit &#269;lena &quot;%s&quot; ze skupiny &quot;%s&quot;?';
	$lang['strmemberdropped'] = '&#268;len odstran&#283;n.';
	$lang['strmemberdroppedbad'] = 'Odstran&#283;n&#237; &#269;lena se nepovedlo.';
	$lang['strmembers'] = '&#268;lenov&#233;';

	// Privileges
	$lang['strprivilege'] = 'Opr&#225;vn&#283;n&#237;';
	$lang['strprivileges'] = 'Opr&#225;vn&#283;n&#237;';
	$lang['strnoprivileges'] = 'Tento objekt nem&#225; opr&#225;vn&#283;n&#237;.';
	$lang['strgrant'] = 'Povolit';
	$lang['strrevoke'] = 'Odobrat';
	$lang['strgranted'] = 'Opr&#225;vn&#283;n&#237; p&#345;idan&#233;.';
	$lang['strgrantbad'] = 'Mus&#237;te specifikovat alespo&#328; jednoho u&#382;ivatele &#269;i skupinu a aspo&#328; jedno opr&#225;vn&#283;n&#237;.';
	$lang['stralterprivs'] = 'Uprav opr&#225;vn&#283;n&#237;';
	$lang['strgrantor'] = 'Poskytovatel opr&#225;vn&#283;n&#237;';
	$lang['strasterisk'] = '*';
	$lang['strgrantfailed'] = 'Opr&#225;vn&#283;n&#237; nebylo p&#345;idan&#233;.';

	
	// Databases
	$lang['strdatabases'] = 'Datab&#225;ze';
	$lang['strshowalldatabases'] = 'Zobrazit v&#353;echny datab&#225;ze';
	$lang['strnodatabase'] = 'Nenalezena &#382;&#225;dn&#225; datab&#225;ze.';
	$lang['strnodatabases'] = 'Nenalezena &#382;&#225;dn&#233; datab&#225;ze.';
	$lang['strcreatedatabase'] = 'Vytvo&#345;it datab&#225;zi';
	$lang['strdatabasename'] = 'N&#225;zev datab&#225;ze';
	$lang['strdatabaseneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev pro datab&#225;zi.';
	$lang['strdatabasecreated'] = 'Datab&#225;ze vytvo&#345;ena.';
	$lang['strsqlexecuted'] = 'SQL provedeno.';
	$lang['strdatabasecreatedbad'] = 'Datab&#225;ze nebyla vytvo&#345;ena.';	
	$lang['strconfdropdatabase'] = 'Opravdu chce&#353; smazat datab&#225;zi &quot;%s&quot;?';
	$lang['strdatabasedropped'] = 'Datab&#225;ze smaz&#225;na.';
	$lang['strdatabasedroppedbad'] = 'Datab&#225;za nebyla smaz&#225;na.';
	$lang['strentersql'] = 'Vlo&#382; SQL dotaz:';
	$lang['strvacuumgood'] = 'Vy&#269;i&#353;t&#283;n&#237; provedeno.';
	$lang['strvacuumbad'] = 'Vy&#269;i&#353;t&#283;n&#237; selhalo.';
	$lang['stranalyzegood'] = 'Anal&#253;za provedena.';
	$lang['stranalyzebad'] = 'Anal&#253;za selhala.';

	// Views
	$lang['strview'] = 'N&#225;hled';
	$lang['strviews'] = 'N&#225;hledy';
	$lang['strshowallviews'] = 'Zobrazit v&#353;echny n&#225;hledy';
	$lang['strnoview'] = 'Nenalezen &#382;&#225;dn&#253; n&#225;hled.';
	$lang['strnoviews'] = 'Nenalezeny &#382;&#225;dn&#233; n&#225;hledy.';
	$lang['strcreateview'] = 'Vytvo&#345;it n&#225;hled';
	$lang['strviewname'] = 'N&#225;zev n&#225;hledu';
	$lang['strviewneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev n&#225;hledu.';
	$lang['strviewneedsdef'] = 'Mus&#237;&#353; zadat definici n&#225;hledu.';
	$lang['strviewcreated'] = 'N&#225;hled vytvo&#345;en.';
	$lang['strviewcreatedbad'] = 'N&#225;hled nebyl vytvo&#345;en.';
	$lang['strviewlink'] = 'Spojovac&#237; kl&#237;&#269;e';
	$lang['strviewconditions'] = 'Uprav podm&#237;nky';
	$lang['strconfdropview'] = 'Opravdu chce&#353; smazat n&#225;hled &quot;%s&quot;?';
	$lang['strviewdropped'] = 'N&#225;hled smaz&#225;n.';
	$lang['strviewdroppedbad'] = 'N&#225;hled nebyl smaz&#225;n.';
	$lang['strviewupdated'] = 'N&#225;hled upraven.';
	$lang['strviewupdatedbad'] = 'N&#225;hled nebyl upraven.';

	// Sequences
	$lang['strsequence'] = 'Sekvence';
	$lang['strsequences'] = 'Sekvence';
	$lang['strshowallsequences'] = 'Zobrazit v&#353;echny sekvence';
	$lang['strnosequence'] = '&#381;&#225;dn&#225; sekvence nenalezena.';
	$lang['strnosequences'] = '&#381;&#225;dn&#253; sekvence nenalezeny.';
	$lang['strcreatesequence'] = 'Vytvorit sekvenci';
	$lang['strlastvalue'] = 'Posledn&#237; hodnota';
	$lang['strincrementby'] = 'Inkrementovat od';	
	$lang['strstartvalue'] = 'Po&#269;&#225;te&#269;n&#237; hodnota';
	$lang['strmaxvalue'] = 'Max hodnota';
	$lang['strminvalue'] = 'Min hodnota';
	$lang['strcachevalue'] = 'Cache hodnota';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = 'Je cyklick&#225;?';
	$lang['strsequenceneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev sekvence.';
	$lang['strsequencereset'] = 'Reset sekvence.';
	$lang['strsequenceresetbad'] = 'Reset sekvence se nepovedl.';
	$lang['strsequencecreated'] = 'Sekvence vytvo&#345;ena.';
	$lang['strsequencecreatedbad'] = 'Sekvence nebyla vytvo&#345;ena.'; 
	$lang['strindex'] = 'Index';
	$lang['strconfdropsequence'] = 'Opravdu chce&#353; smazat sekvence &quot;%s&quot;?';
	$lang['strsequencedropped'] = 'Sekvence smaz&#225;na.';
	$lang['strsequencedroppedbad'] = 'Sekvence nebyla smaz&#225;na.';

	// Indexes
	$lang['strindexes'] = 'Indexy';
	$lang['strindexname'] = 'N&#225;zev indexu';
	$lang['strshowallindexes'] = 'Zobrazit v&#353;echny indexy';
	$lang['strnoindex'] = 'Nenalezen &#382;&#225;dn&#253; index.';
	$lang['strnoindexes'] = 'Nenalezeny &#382;&#225;dn&#233; index.';
	$lang['strcreateindex'] = 'Vytvo&#345;it index';
	$lang['strindexname'] = 'N&#225;zev indexu';
	$lang['strtabname'] = 'N&#225;zev tabulky';
	$lang['strcolumnname'] = 'N&#225;zov stoupce';
	$lang['strindexneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev indexu';
	$lang['strindexneedscols'] = 'Index vy&#382;aduje korektn&#237; po&#269;et sloupc&#367;.';
	$lang['strindexcreated'] = 'Index vytvo&#345;en';
	$lang['strindexcreatedbad'] = 'Index nebyl vytvo&#345;en.';
	$lang['strconfdropindex'] = 'Opravdu chce&#353; smazat index &quot;%s&quot;?';
	$lang['strindexdropped'] = 'Index smaz&#225;n.';
	$lang['strindexdroppedbad'] = 'Index nebyl smaz&#225;n.';
	$lang['strconfcluster'] = 'Chcete opravdu clusterovat &quot;%s&quot;?';
	$lang['strclusteredgood'] = 'Cluster proveden.';
	$lang['strclusteredbad'] = 'Cluster se nepovedl.';
	$lang['strkeyname'] = 'N&#225;zev kl&#237;&#269;e';
	$lang['struniquekey'] = 'Unik&#225;tn&#237; kl&#237;&#269;';
	$lang['strprimarykey'] = 'Prim&#225;rn&#237; kl&#237;&#269;';
 	$lang['strindextype'] = 'Typ indexu';
	$lang['strindexname'] = 'N&#225;zev indexu';
	$lang['strtablecolumnlist'] = 'Sloupce v tabulce';
	$lang['strindexcolumnlist'] = 'Sloupce v indexu';

	// Rules
	$lang['strrules'] = 'Pravidla';
	$lang['strrule'] = 'Pravidlo';
	$lang['strshowallrules'] = 'Zobrazit v&#353;echna pravidla';
	$lang['strnorule'] = 'Nenalezeno &#382;&#225;dn&#233; pravidlo.';
	$lang['strnorules'] = 'Nenalezeny &#382;&#225;dn&#225; pravidla.';
	$lang['strcreaterule'] = 'Vytvo&#345;it pravidlo';
	$lang['strrulename'] = 'N&#225;zev pravidla';
	$lang['strruleneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev pravidla.';
	$lang['strrulecreated'] = 'Pravidlo vytvo&#345;eno.';
	$lang['strrulecreatedbad'] = 'Pravidlo nebylo vytvo&#345;eno.';
	$lang['strconfdroprule'] = 'Chce&#353; opravdu smazat pravidlo &quot;%s&quot; na &quot;%s&quot;?';
	$lang['strruledropped'] = 'Pravidlo smaz&#225;no.';
	$lang['strruledroppedbad'] = 'Pravidlo nebylo smaz&#225;no.';

	// Constraints
	$lang['strconstraints'] = 'Omezen&#237;';
	$lang['strshowallconstraints'] = 'Zobrazit v&#353;echna omezen&#237;';
	$lang['strnoconstraints'] = 'Nenalezeny &#382;&#225;dn&#233; omezen&#237;.';
	$lang['strcreateconstraint'] = 'Vytvo&#345;it omezen&#237;';
	$lang['strconstraintcreated'] = 'Omezen&#237; vytvo&#345;eno.';
	$lang['strconstraintcreatedbad'] = 'Omezen&#237; nebylo vytvo&#345;eno.';
	$lang['strconfdropconstraint'] = 'Chce&#353; opravdu smazat omezen&#237; &quot;%s&quot; na &quot;%s&quot;?';
	$lang['strconstraintdropped'] = 'Omezen&#237; smaz&#225;no.';
	$lang['strconstraintdroppedbad'] = 'Omezen&#237; nebylo smaz&#225;no.';
	$lang['straddcheck'] = 'P&#345;idat kontrolu';
	$lang['strcheckneedsdefinition'] = 'Je nutn&#233; kontrolu omezen&#237; definovat.';
	$lang['strcheckadded'] = 'Kontrola omezen&#237; p&#345;id&#225;na.';
	$lang['strcheckaddedbad'] = 'Kontrola omezen&#237; nebyla p&#345;id&#225;na.';
	$lang['straddpk'] = 'P&#345;idat prim&#225;rn&#237; kl&#237;&#269;';
	$lang['strpkneedscols'] = 'Prim&#225;rn&#237; kl&#237;&#269; vy&#382;aduje alespo&#328; jeden sloupec.';
	$lang['strpkadded'] = 'Prim&#225;rn&#237; kl&#237;&#269; p&#345;id&#225;n.';
	$lang['strfkneedstarget'] = 'Ciz&#237; kl&#237;&#269; vy&#382;aduje c&#237;lovou tabulku.';
	$lang['strpkaddedbad'] = 'Prim&#225;rn&#237; kl&#237;&#269; nebyl p&#345;id&#225;n.';
	$lang['stradduniq'] = 'P&#345;idat unik&#225;tn&#237; kl&#237;&#269;';
	$lang['struniqneedscols'] = 'Unik&#225;tn&#237; kl&#237;&#269; vy&#382;aduje alespo&#328; jeden sloupec.';
	$lang['strfkcolumnlist'] = 'Sloupce v kl&#237;&#269;i';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';
	$lang['struniqadded'] = 'Unik&#225;tn&#237; kl&#237;&#269; p&#345;id&#225;n.';
	$lang['struniqaddedbad'] = 'Unik&#225;tn&#237; kl&#237;&#269; nebyl p&#345;id&#225;n.';
	$lang['straddfk'] = 'P&#345;idat ciz&#237; kl&#237;&#269;';
	$lang['strfkneedscols'] = 'Ciz&#237; kl&#237;&#269; vy&#382;aduje alespo&#328; jeden sloupec.';
	$lang['strfkadded'] = 'Ciz&#237; kl&#237;&#269; p&#345;id&#225;n.';
	$lang['strfkaddedbad'] = 'Ciz&#237; kl&#237;&#269; nebyl p&#345;id&#225;n.';
	$lang['strfktarget'] = 'C&#237;lov&#225; tabulka';

	// Functions
	$lang['strfunction'] = 'Funkce';
	$lang['strfunctions'] = 'Funkce';
	$lang['strshowallfunctions'] = 'Zobrazit v&#353;echny funkce';
	$lang['strnofunction'] = 'Nenalezena &#382;&#225;dn&#225; funkce.';
	$lang['strnofunctions'] = 'Nenalezeny &#382;&#225;dn&#233; funkce.';
	$lang['strcreatefunction'] = 'Vytvo&#345;it funkci';
	$lang['strfunctionname'] = 'N&#225;zev funkce';
	$lang['strreturns'] = 'Vrac&#237;';
	$lang['strarguments'] = 'Argumenty';
	$lang['strproglanguage'] = 'Jazyk';
	$lang['strfunctionneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev funkce.';
	$lang['strfunctionneedsdef'] = 'Mus&#237;&#353; zadat definici funkce.';
	$lang['strfunctioncreated'] = 'Funkce vytvo&#345;ena.';
	$lang['strfunctioncreatedbad'] = 'Funkce nebyla vytvo&#345;ena.';
	$lang['strconfdropfunction'] = 'Opravdu chce&#353; smazat funkci &quot;%s&quot;?';
	$lang['strfunctiondropped'] = 'Funkce smaz&#225;na.';
	$lang['strfunctiondroppedbad'] = 'Funkce nebyla smaz&#225;na.';
	$lang['strfunctionupdated'] = 'Funkce upravena.';
	$lang['strfunctionupdatedbad'] = 'Funkce nebyla upravena.';

	// Triggers
	$lang['strtrigger'] = 'Trigger';
	$lang['strtriggers'] = 'Triggers';
	$lang['strshowalltriggers'] = 'Zobrazit v&#353;echny triggery';
	$lang['strnotrigger'] = 'Nenalezen &#382;&#225;dn&#253; trigger.';
	$lang['strnotriggers'] = 'Nenalezeny &#382;&#225;dn&#233; triggery.';
	$lang['strcreatetrigger'] = 'Vytvo&#345;it trigger';
	$lang['strtriggeraltered'] = 'Trigger zm&#283;n&#283;n.';
	$lang['strtriggeralteredbad'] = 'Zm&#283;na triggeru se nepovedla.';
	$lang['strtriggerneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev triggeru.';
	$lang['strtriggerneedsfunc'] = 'Mus&#237;&#353; zadat funkci triggeru.';
	$lang['strtriggercreated'] = 'Trigger vytvo&#345;en.';
	$lang['strtriggercreatedbad'] = 'Trigger nebyl vytvo&#345;en.';
	$lang['strconfdroptrigger'] = 'Chce&#353; opravdu smazat trigger &quot;%s&quot; na &quot;%s&quot;?';
	$lang['strtriggerdropped'] = 'Trigger smaz&#225;n.';
	$lang['strtriggerdroppedbad'] = 'Trigger nebyl smaz&#225;n.';

	// Types
	$lang['strtype'] = 'Typ';
	$lang['strtypes'] = 'Typy';
	$lang['strshowalltypes'] = 'Zobrazit v&#353;echny typy';
	$lang['strnotype'] = 'Nenalezen&#253; &#382;&#225;dn&#253; typ.';
	$lang['strnotypes'] = 'Nenalezeny &#382;&#225;dn&#233; typy.';
	$lang['strcreatetype'] = 'Vytvo&#345;it typ';
	$lang['strtypename'] = 'N&#225;zev typu';
	$lang['strinputfn'] = 'Vstupn&#237; funkce';
	$lang['stroutputfn'] = 'V&#253;stupn&#237; funkce';
	$lang['strpassbyval'] = 'Vol&#225;n hodnotou?';
	$lang['stralignment'] = 'Zarovn&#225;n&#237;';
	$lang['strelement'] = 'Element';
	$lang['strdelimiter'] = 'Odd&#283;lova&#269;';
	$lang['strstorage'] = 'Storage';
	$lang['strtypeneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev typu.';
	$lang['strtypeneedslen'] = 'Mus&#237;&#353; zadat d&#233;lku typu.';
	$lang['strtypecreated'] = 'Typ vytvo&#345;en.';
	$lang['strtypecreatedbad'] = 'Typ nebyl vytvo&#345;en.';
	$lang['strconfdroptype'] = 'Chce&#353; opravdu smazat typ &quot;%s&quot;?';
	$lang['strtypedropped'] = 'Typ smaz&#225;n.';
	$lang['strtypedroppedbad'] = 'Typ nebyl smaz&#225;n.';

	// Schemas
	$lang['strschema'] = 'Sch&#233;ma';
	$lang['strschemas'] = 'Sch&#233;mata';
	$lang['strshowallschemas'] = 'Zobrazit v&#353;echny sch&#233;mata';
	$lang['strnoschema'] = 'Nenalezeno &#382;&#225;dn&#233; sch&#233;ma.';
	$lang['strnoschemas'] = 'Nenalezeny &#382;&#225;dn&#233; sch&#233;mata.';
	$lang['strcreateschema'] = 'Vytvorit sch&#233;ma';
	$lang['strschemaname'] = 'N&#225;zev sch&#233;matu';
	$lang['strschemaneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev sch&#233;matu.';
	$lang['strschemacreated'] = 'Sch&#233;ma vytvo&#345;eno.';
	$lang['strschemacreatedbad'] = 'Sch&#233;ma nebylo vytvo&#345;eno.';
	$lang['strconfdropschema'] = 'Chce&#353; opravdu smazat sch&#233;ma &quot;%s&quot;?';
	$lang['strschemadropped'] = 'Sch&#233;ma smaz&#225;no.';
	$lang['strschemadroppedbad'] = 'Sch&#233;ma nebylo smaz&#225;no.';

	// Reports
	$lang['strreport'] = 'Report';
	$lang['strreports'] = 'Reporty';
	$lang['strshowallreports'] = 'Zobrazit v&#353;echny reporty';
	$lang['strnoreports'] = 'Nenalezeny &#382;&#225;dn&#233; reporty.';
	$lang['strcreatereport'] = 'Vytvo&#345;it report';
	$lang['strreportdropped'] = 'Report smaz&#225;n.';
	$lang['strreportdroppedbad'] = 'Report nebyl smaz&#225;n.';
	$lang['strdomain'] = 'Dom&#233;na';
	$lang['strdomains'] = 'Dom&#233;ny';
	$lang['strshowalldomains'] = 'Uka&#382; v&#353;echny dom&#233;ny';
	$lang['strnodomains'] = '&#381;&#225;dn&#233; dom&#233;ny nenalezeny.';
	$lang['strcreatedomain'] = 'Vytvo&#345; dom&#233;nu';
	$lang['strdomaindropped'] = 'Dom&#233;na odstran&#283;na.';
	$lang['strdomaindroppedbad'] = 'Odstran&#283;n&#237; dom&#233;ny se nepovedlo.';
	$lang['strconfdropdomain'] = 'Chce&#353; opravdu odstranit dom&#233;nu &quot;%s&quot;?';
	$lang['strdomainneedsname'] = 'Mus&#237;te zadat jm&#233;no dom&#233;ny.';
	$lang['strdomaincreated'] = 'Dom&#233;na vytvo&#345;ena.';
	$lang['strdomaincreatedbad'] = 'Vytvo&#345;en&#237; dom&#233;ny se nepovedlo.';
	$lang['strdomainaltered'] = 'Domain zm&#283;n&#283;na.';
	$lang['strdomainalteredbad'] = 'Zm&#283;na dom&#233;ny se nepovelda.';
	$lang['strconfdropreport'] = 'Opravdu chce&#353; smazat report &quot;%s&quot;?';
	$lang['strreportneedsname'] = 'Mus&#237;&#353; zadat n&#225;zev reportu.';
	$lang['stroperator'] = 'Oper&#225;tor';
	$lang['strreportneedsdef'] = 'Mus&#237;&#353; zadat SQL dotaz pro report.';
	$lang['strshowalloperators'] = 'Uka&#382; v&#353;echny oper&#225;tory';
	$lang['strnooperator'] = '&#381;&#225;dn&#253; oper&#225;tor nenalezen.';
	$lang['strnooperators'] = '&#381;&#225;dn&#233; oper&#225;tory nenalezeny.';
	$lang['strcreateoperator'] = 'Vytvo&#345; oper&#225;tor';
	$lang['strleftarg'] = 'Typ lev&#233;ho argumentu';
	$lang['strrightarg'] = 'Typ prav&#233;ho argumenti';
	$lang['strcommutator'] = 'Komut&#225;tor';
	$lang['strnegator'] = 'Neg&#225;tor';
	$lang['strrestrict'] = 'Omezen&#237;';
	$lang['strjoin'] = 'Join';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Lev&#233; t&#345;&#237;d&#283;n&#237;';
	$lang['strrightsort'] = 'Prav&#233; t&#345;&#237;d&#283;n&#237;';
	$lang['strlessthan'] = 'M&#233;n&#283; ne&#382;';
	$lang['strgreaterthan'] = 'V&#237;ce ne&#382;';
	$lang['stroperatorneedsname'] = 'Mus&#237;te zadat jm&#233;no oper&#225;toru.';
	$lang['stroperatorcreated'] = 'Oper&#225;tor vytvo&#345;en';
	$lang['stroperatorcreatedbad'] = 'Vytvo&#345;en&#237; oper&#225;toru se nepovedlo.';
	$lang['strconfdropoperator'] = 'Opravdu chce&#353; smazat oper&#225;tor &quot;%s&quot;?';
	$lang['stroperatordropped'] = 'Oper&#225;tor smaz&#225;n.';
	$lang['stroperatordroppedbad'] = 'Smaz&#225;n&#237; oper&#225;toru se nepovedlo.';
	$lang['strreportcreated'] = 'Report ulo&#382;en.';
	$lang['strreportcreatedbad'] = 'Report nebyl ulo&#382;en.';
	$lang['strcasts'] = 'Casts';
	$lang['strnocasts'] = 'No casts found.';
	$lang['strsourcetype'] = 'Zdrojov&#253; typ';
	$lang['strtargettype'] = 'C&#237;lov&#253; typ';
	$lang['strimplicit'] = 'Implictn&#283;';
	$lang['strinassignment'] = 'V p&#345;i&#345;azen&#237;';
	$lang['strbinarycompat'] = '(bin&#225;rn&#283; kompatibiln&#237;)';

	// Miscellaneous
	$lang['strconversions'] = 'Konverze';
	$lang['strnoconversions'] = '&#381;&#225;dn&#233; konverze nenalezeny.';
	$lang['strsourceencoding'] = 'Zdrojov&#233; k&#243;dov&#225;n&#237;';
	$lang['strtargetencoding'] = 'Cilov&#233; k&#243;dov&#225;n&#237;';
	$lang['strtopbar'] = '%s be&#382;&#237; na %s:%s -- Jsi p&#345;ihl&#225;&#353;en&#253; jako &quot;%s&quot;, %s';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strlanguages'] = 'Jazyky';
	$lang['strnolanguages'] = '&#381;&#225;dn&#233; jazyky nenalezeny.';
	$lang['strtrusted'] = 'D&#367;v&#283;ryhodn&#253;';

	$lang['strdataonly'] = 'Pouze data';
	$lang['strusers'] = 'U&#382;ivatel&#233;';
	$lang['strnogroup'] = 'Skupina nenalezena.';
	$lang['strdatabase'] = 'Datab&#225;ze';
	$lang['strnoinfo'] = 'Nejsou dostupn&#233; &#382;&#225;dn&#233; informace.';
	$lang['strreferringtables'] = 'Odkazovan&#233; tabulky';
	$lang['strparenttables'] = 'Tabulky rodi&#269;&#367;';
	$lang['strchildtables'] = 'Tabulky potomk&#367;';
	$lang['strnoaggregates'] = 'Nebyla nalezena &#382;&#225;dn&#225; agregace.';
	$lang['stralltypes'] = '(V&#353;echny typy)';
	$lang['stropclasses'] = 'T&#345;&#237;dy oper&#225;tor&#367;';
	$lang['strnoopclasses'] = 'Nebyly nalezeny &#382;&#225;dn&#233; t&#345;&#237;dy oper&#225;tor&#367;.';
	$lang['straccessmethod'] = 'P&#345;&#237;stupov&#225; metoda';	
	$lang['strrowperf'] = 'V&#253;kon &#345;&#225;dku';
	$lang['strioperf'] = 'I/O v&#253;kon';
	$lang['stridxrowperf'] = 'V&#253;kon indexu &#345;&#225;dku';
	$lang['stridxioperf'] = 'I/O v&#253;kon indexu';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sekven&#269;n&#237;&#233;';
	$lang['strscan'] = 'Scan';
	$lang['strread'] = 'Read';
	$lang['strfetch'] = 'Fetch';
	$lang['strheap'] = 'Heap';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST Index';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disk';
	$lang['strrows2'] = '&#344;&#225;dk&#367;';
	$lang['strhelp'] = 'N&#225;pov&#283;da';

?>
